@@ -52,7 +52,7 @@ static QString getNext(QString *str)
 		++n;
 	}
 	if(n == (int)str->length()) {
-		return QString::null;
+		return QString();
 	}
 	// find end or next space
 	while(n < (int)str->length() && !str->at(n).isSpace()) {
@@ -72,7 +72,7 @@ static QStringList wrapString(const QString &str, int wid)
 	//printf("parsing: [%s]\n", tmp.latin1());
 	while(1) {
 		QString word = getNext(&tmp);
-		if(word == QString::null) {
+		if(word == QString()) {
 			lines += cur;
 			break;
 		}
@@ -937,8 +937,10 @@ void HistoryDlg::highlightBlocks()
 {
 	const QString text = ui_.searchField->text();
 	QTextCursor cur = ui_.msgLog->textCursor();
-	QTextCursor old = cur;
-	int sc_pos = ui_.msgLog->verticalScrollBar()->value();
+    QTextCursor old = cur;
+    int sc_pos = 0;
+    if (ui_.msgLog->verticalScrollBar())
+        sc_pos = ui_.msgLog->verticalScrollBar()->value();
 	cur.clearSelection();
 	cur.movePosition(QTextCursor::Start);
 	ui_.msgLog->setTextCursor(cur);
@@ -958,8 +960,9 @@ void HistoryDlg::highlightBlocks()
 	}
 
 	ui_.msgLog->setExtraSelections(extras);
-	ui_.msgLog->setTextCursor(old);
-	ui_.msgLog->verticalScrollBar()->setValue(sc_pos);
+    ui_.msgLog->setTextCursor(old);
+    if (ui_.msgLog->verticalScrollBar())
+        ui_.msgLog->verticalScrollBar()->setValue(sc_pos);
 }
 
 void HistoryDlg::findMessages()
