@@ -665,7 +665,7 @@ QString IconButton::psiIconName() const
 #ifndef WIDGET_PLUGIN
 	if ( d->icon )
 		return d->icon->name();
-	return QString::null;
+    return QString();
 #else
 	return d->iconName;
 #endif
@@ -818,7 +818,7 @@ QString IconToolButton::psiIconName() const
 #ifndef WIDGET_PLUGIN
 	if ( d->icon )
 		return d->icon->name();
-	return QString::null;
+    return QString();
 #else
 	return d->iconName;
 #endif
